'use strict';

var path = require('path');
var svelte = require('svelte');
var rollupPluginutils = require('rollup-pluginutils');

function sanitize ( input ) {
	return path.basename( input )
		.replace( path.extname( input ), '' )
		.replace( /[^a-zA-Z_$0-9]+/g, '_' )
		.replace( /^_/, '' )
		.replace( /_$/, '' )
		.replace( /^(\d)/, '_$1' );
}

function capitalize ( str ) {
	return str[0] + str.slice( 1 );
}

function svelte$1 ( options ) {
	if ( options === void 0 ) options = {};

	var filter = rollupPluginutils.createFilter( options.include, options.exclude );

	var extensions = options.extensions || [ '.html', '.svelte' ];

	return {
		name: 'svelte',

		transform: function transform ( code, id ) {
			if ( !filter( id ) ) { return null; }
			if ( !~extensions.indexOf( path.extname( id ) ) ) { return null; }

			var name = capitalize( sanitize( id ) );

			return svelte.compile( code, {
				name: name,
				filename: id,
				css: options.css,
				generate: options.generate,
				format: 'es',
				shared: require.resolve( 'svelte/shared.js' ),

				onerror: function onerror ( err ) {
					var message = ( err.loc ? ("(" + (err.loc.line) + ":" + (err.loc.column) + ") ") : '' ) + err.message;
					if ( err.frame ) { message += "\n" + (err.frame); }

					var err2 = new Error( message );
					err2.stack = err.stack;

					throw err2;
				}
			});
		}
	};
}

module.exports = svelte$1;
